==> haskell-what4-1.6-18-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-what4.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 what4
version:              1.6
visibility:           public
id:                   what4-1.6-pAaDa7UWFPBM6TZDLyneE
key:                  what4-1.6-pAaDa7UWFPBM6TZDLyneE
license:              BSD-3-Clause
copyright:            (c) Galois, Inc 2014-2023
maintainer:           rscott@galois.com, kquick@galois.com
author:               Galois Inc.
homepage:             https://github.com/GaloisInc/what4
synopsis:             Solver-agnostic symbolic values support for issuing queries
description:
    What4 is a generic library for representing values as symbolic formulae which may
    contain references to symbolic values, representing unknown variables.
    It provides support for communicating with a variety of SAT and SMT solvers,
    including Z3, CVC4, CVC5, Yices, Bitwuzla, Boolector, STP, and dReal.
    The data representation types make heavy use of GADT-style type indices
    to ensure type-correct manipulation of symbolic values.

category:             Formal Methods, Theorem Provers, Symbolic Computation, SMT
abi:                  757fd647a3d88e89b790b3a64ab2b55d
exposed:              True
exposed-modules:
    Test.Verification What4.BaseTypes What4.Concrete What4.Config
    What4.Expr What4.Expr.Allocator What4.Expr.App What4.Expr.AppTheory
    What4.Expr.ArrayUpdateMap What4.Expr.BoolMap What4.Expr.Builder
    What4.Expr.GroundEval What4.Expr.MATLAB What4.Expr.Simplify
    What4.Expr.StringSeq What4.Expr.UnaryBV
    What4.Expr.VarIdentification What4.Expr.WeightedSum What4.FloatMode
    What4.FunctionName What4.IndexLit What4.Interface
    What4.InterpretedFloatingPoint What4.LabeledPred What4.Panic
    What4.Partial What4.ProblemFeatures What4.ProgramLoc
    What4.Protocol.Online What4.Protocol.PolyRoot
    What4.Protocol.ReadDecimal What4.Protocol.SExp
    What4.Protocol.SMTLib2 What4.Protocol.SMTLib2.Parse
    What4.Protocol.SMTLib2.Response What4.Protocol.SMTLib2.Syntax
    What4.Protocol.SMTWriter What4.Protocol.VerilogWriter
    What4.Protocol.VerilogWriter.ABCVerilog
    What4.Protocol.VerilogWriter.AST
    What4.Protocol.VerilogWriter.Backend What4.SFloat What4.SWord
    What4.SatResult What4.SemiRing What4.Serialize.FastSExpr
    What4.Serialize.Log What4.Serialize.Normalize
    What4.Serialize.Parser What4.Serialize.Printer
    What4.Serialize.SETokens What4.Solver What4.Solver.Adapter
    What4.Solver.Bitwuzla What4.Solver.Boolector What4.Solver.CVC4
    What4.Solver.CVC5 What4.Solver.DReal What4.Solver.ExternalABC
    What4.Solver.STP What4.Solver.Yices What4.Solver.Z3
    What4.SpecialFunctions What4.Symbol What4.Utils.AbstractDomains
    What4.Utils.AnnotatedMap What4.Utils.Arithmetic
    What4.Utils.BVDomain What4.Utils.BVDomain.Arith
    What4.Utils.BVDomain.Bitwise What4.Utils.BVDomain.XOR
    What4.Utils.Complex What4.Utils.Endian What4.Utils.Environment
    What4.Utils.FloatHelpers What4.Utils.HandleReader
    What4.Utils.IncrHash What4.Utils.LeqMap What4.Utils.MonadST
    What4.Utils.OnlyIntRepr What4.Utils.Process
    What4.Utils.ResolveBounds.BV What4.Utils.Serialize
    What4.Utils.Streams What4.Utils.StringLiteral What4.Utils.Versions
    What4.Utils.Word16String What4.WordMap

import-dirs:          /usr/lib/ghc-9.4.8/site-local/what4-1.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/what4-1.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/what4-1.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-what4
hs-libraries:         HSwhat4-1.6-pAaDa7UWFPBM6TZDLyneE
depends:
    BoundedChan-1.0.3.0-LpypBc0eid95svZdMy7DB6
    async-2.2.5-LqkzH7L8HyYHud0cQFVYjz
    attoparsec-0.14.4-a7MjceIUMFKMmgfXk7t7H base-4.17.2.1
    bifunctors-5.6.2-GJAIxjboOUJCLo1omQh6ZU
    bimap-0.5.0-HcMrsNSX0KU1SVhuPcFF1q
    bv-sized-1.0.6-8pJJE12e1faJUsIjFznwr8 bytestring-0.11.5.3
    concurrent-extra-0.7.0.12-5RVK56WfMYzEYqvaYcP4kj
    config-value-0.8.3-AwfdtSmE9Y1aqPSXDWTLH containers-0.6.7
    deepseq-1.4.8.0 deriving-compat-0.6.7-QpfuSEE5mDcgUOBArb2W
    directory-1.3.7.1 exceptions-0.10.5 filepath-1.4.2.2
    fingertree-0.1.6.2-6zCukH8CO9r5Iv8fnDWMZW ghc-prim-0.9.1
    hashable-1.4.4.0-BPBogvz51gTFqjBeDWtSVb
    hashtables-1.4.1-Ex5GSdQJGpJ9VswrVKEMQJ
    io-streams-1.5.2.2-K5IjzkNNmAf7LdMcsmPYbB
    lens-5.3.1-9oQplfPnoWr2g52V8zm4go
    libBF-0.6.6-AcTjhXmY613Eh7bHxOJz42
    megaparsec-9.7.0-DEUv5YUmdT01sIVP4Xv3Ec mtl-2.2.2
    ordered-containers-0.2.4-4T6ycs3BOXS3ROZt30LpDs
    panic-0.4.0.1-3HuynR94lzrCKtPGBGvV9o
    parameterized-utils-2.1.10.0-4U6aroq0yjy1Pex3KXaEUe parsec-3.1.16.1
    prettyprinter-1.7.1-AUeOQjFrPgDFiTKCjRnpzw process-1.6.18.0
    s-cargot-0.1.6.0-JEPoGR1aSZZJ9WUcBcaNqu
    scientific-0.3.8.0-KN45uED49ez8IbcjYjrLBN stm-2.5.1.0
    template-haskell-2.19.0.0 temporary-1.3-9rtP6hocReL6fK4gSjxIEA
    text-2.0.2 th-lift-0.8.5-3bCWMcLwp8dEXoRnv4Yrhx
    th-lift-instances-0.1.20-6A9vs3XVslTHgRJodRaMgs time-1.12.2
    transformers-0.5.6.2 unliftio-0.2.25.1-HM0R1ty4e2TDt6fGDzBedX
    unordered-containers-0.2.20-7dvM9aaOf5JATet72j0BPX
    utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm
    vector-0.13.2.0-JDMr93x2QgFDQPvksTJZzq
    versions-6.0.8-GDuoX9fLESIA9K2cwmgdHP
    zenc-0.1.2-8Qle34FXBgc8xTGrN7B0HZ

haddock-interfaces:   /usr/share/doc/haskell-what4/html/what4.haddock
haddock-html:         /usr/share/doc/haskell-what4/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-what4-1.6-19-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-what4.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 what4
version:              1.6
visibility:           public
id:                   what4-1.6-GYUM1ePOYDpFCBEqQJ4oPK
key:                  what4-1.6-GYUM1ePOYDpFCBEqQJ4oPK
license:              BSD-3-Clause
copyright:            (c) Galois, Inc 2014-2023
maintainer:           rscott@galois.com, kquick@galois.com
author:               Galois Inc.
homepage:             https://github.com/GaloisInc/what4
synopsis:             Solver-agnostic symbolic values support for issuing queries
description:
    What4 is a generic library for representing values as symbolic formulae which may
    contain references to symbolic values, representing unknown variables.
    It provides support for communicating with a variety of SAT and SMT solvers,
    including Z3, CVC4, CVC5, Yices, Bitwuzla, Boolector, STP, and dReal.
    The data representation types make heavy use of GADT-style type indices
    to ensure type-correct manipulation of symbolic values.

category:             Formal Methods, Theorem Provers, Symbolic Computation, SMT
abi:                  9c707f9938b15d89ee7ddf48df40fba4
exposed:              True
exposed-modules:
    Test.Verification What4.BaseTypes What4.Concrete What4.Config
    What4.Expr What4.Expr.Allocator What4.Expr.App What4.Expr.AppTheory
    What4.Expr.ArrayUpdateMap What4.Expr.BoolMap What4.Expr.Builder
    What4.Expr.GroundEval What4.Expr.MATLAB What4.Expr.Simplify
    What4.Expr.StringSeq What4.Expr.UnaryBV
    What4.Expr.VarIdentification What4.Expr.WeightedSum What4.FloatMode
    What4.FunctionName What4.IndexLit What4.Interface
    What4.InterpretedFloatingPoint What4.LabeledPred What4.Panic
    What4.Partial What4.ProblemFeatures What4.ProgramLoc
    What4.Protocol.Online What4.Protocol.PolyRoot
    What4.Protocol.ReadDecimal What4.Protocol.SExp
    What4.Protocol.SMTLib2 What4.Protocol.SMTLib2.Parse
    What4.Protocol.SMTLib2.Response What4.Protocol.SMTLib2.Syntax
    What4.Protocol.SMTWriter What4.Protocol.VerilogWriter
    What4.Protocol.VerilogWriter.ABCVerilog
    What4.Protocol.VerilogWriter.AST
    What4.Protocol.VerilogWriter.Backend What4.SFloat What4.SWord
    What4.SatResult What4.SemiRing What4.Serialize.FastSExpr
    What4.Serialize.Log What4.Serialize.Normalize
    What4.Serialize.Parser What4.Serialize.Printer
    What4.Serialize.SETokens What4.Solver What4.Solver.Adapter
    What4.Solver.Bitwuzla What4.Solver.Boolector What4.Solver.CVC4
    What4.Solver.CVC5 What4.Solver.DReal What4.Solver.ExternalABC
    What4.Solver.STP What4.Solver.Yices What4.Solver.Z3
    What4.SpecialFunctions What4.Symbol What4.Utils.AbstractDomains
    What4.Utils.AnnotatedMap What4.Utils.Arithmetic
    What4.Utils.BVDomain What4.Utils.BVDomain.Arith
    What4.Utils.BVDomain.Bitwise What4.Utils.BVDomain.XOR
    What4.Utils.Complex What4.Utils.Endian What4.Utils.Environment
    What4.Utils.FloatHelpers What4.Utils.HandleReader
    What4.Utils.IncrHash What4.Utils.LeqMap What4.Utils.MonadST
    What4.Utils.OnlyIntRepr What4.Utils.Process
    What4.Utils.ResolveBounds.BV What4.Utils.Serialize
    What4.Utils.Streams What4.Utils.StringLiteral What4.Utils.Versions
    What4.Utils.Word16String What4.WordMap

import-dirs:          /usr/lib/ghc-9.4.8/site-local/what4-1.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/what4-1.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/what4-1.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-what4
hs-libraries:         HSwhat4-1.6-GYUM1ePOYDpFCBEqQJ4oPK
depends:
    BoundedChan-1.0.3.0-LpypBc0eid95svZdMy7DB6
    async-2.2.5-BcqMz9kSLpQJiwvDzQjiwa
    attoparsec-0.14.4-FKpKWqwLteZDlwxf33yCFk base-4.17.2.1
    bifunctors-5.6.2-3TxVuRiTNI4J1Q4fsA2nS
    bimap-0.5.0-LsjljVJxFIuDtiVxAucQ6e
    bv-sized-1.0.6-3rMJ6YsZ0fIEHuML5CtyjC bytestring-0.11.5.3
    concurrent-extra-0.7.0.12-2tSzNANBqASShjPQ05F8c
    config-value-0.8.3-AwfdtSmE9Y1aqPSXDWTLH containers-0.6.7
    deepseq-1.4.8.0 deriving-compat-0.6.7-CZU9xi6zP5vDfZBKi1RWvY
    directory-1.3.7.1 exceptions-0.10.5 filepath-1.4.2.2
    fingertree-0.1.6.2-DDCdDkMdrSjD2rI9vZMZ1N ghc-prim-0.9.1
    hashable-1.4.4.0-KHdv63hvW7JkoOGsLWKac
    hashtables-1.4.1-GtEU3sLJ0nlAZvnFjDQZh6
    io-streams-1.5.2.2-Lc9jp7HstmCBhGo4hU2E1L
    lens-5.3.1-6s7OGBiqW0t1WJAI91dKgc
    libBF-0.6.6-52pO3yoPXEP7z0kHAaKsLo
    megaparsec-9.7.0-7JToewzpODIKYsxdMWTRd1 mtl-2.2.2
    ordered-containers-0.2.4-29kQoTxtpE33yG7vN5e2e6
    panic-0.4.0.1-3HuynR94lzrCKtPGBGvV9o
    parameterized-utils-2.1.10.0-FZIbLyYUQWfLipp8gHPdru parsec-3.1.16.1
    prettyprinter-1.7.1-K25tjwTKXuP4KBelsyCegB process-1.6.18.0
    s-cargot-0.1.6.0-7apKFgljEh0LGUzzt4jxtC
    scientific-0.3.8.0-JD5EMEyFBUc5yMNfC55Oq6 stm-2.5.1.0
    template-haskell-2.19.0.0 temporary-1.3-H3SteNwKbkKBCt6CIyC5cW
    text-2.0.2 th-lift-0.8.5-3bCWMcLwp8dEXoRnv4Yrhx
    th-lift-instances-0.1.20-CZv5UcUxK4JJQ4zAbS7ny8 time-1.12.2
    transformers-0.5.6.2 unliftio-0.2.25.1-Hl9F86nOgLZ6fT5FacqWN
    unordered-containers-0.2.20-1i1FNKzvn6TI2R1AzcNrcz
    utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm
    vector-0.13.2.0-FNdsFzivQrc5gVfjRMxS7n
    versions-6.0.8-BSeNhsm3wxK8HbmH5KuLCY
    zenc-0.1.2-6SzlgRdLBukKYu1kKOK4d6

haddock-interfaces:   /usr/share/doc/haskell-what4/html/what4.haddock
haddock-html:         /usr/share/doc/haskell-what4/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
